sequencetools.partition_sequence_by_restricted_growth_function
==============================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_by_restricted_growth_function.partition_sequence_by_restricted_growth_function
